summaryrefslogtreecommitdiff
path: root/src/game/g_maprotation.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/game/g_maprotation.c')
-rw-r--r--src/game/g_maprotation.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/game/g_maprotation.c b/src/game/g_maprotation.c
index 0487079c..e6d773e8 100644
--- a/src/game/g_maprotation.c
+++ b/src/game/g_maprotation.c
@@ -891,10 +891,10 @@ static void G_IssueMapChange( int index, int rotation )
node_t *node = mapRotations.rotations[ rotation ].nodes[ index ];
map_t *map = &node->u.map;
- // allow a manually defined g_layouts setting to override the maprotation
- if( !g_layouts.string[ 0 ] && map->layouts[ 0 ] )
+ // allow a manually defined g_nextLayout setting to override the maprotation
+ if( !g_nextLayout.string[ 0 ] && map->layouts[ 0 ] )
{
- trap_Cvar_Set( "g_layouts", map->layouts );
+ trap_Cvar_Set( "g_nextLayout", map->layouts );
}
G_PerformMapChange( map->name );